Fil.AccessDeniedError exception (Fil v0.1.0)

Copy Markdown View Source

The storage refused access. Fix the permissions or the credentials.

Adapters return it for missing file permissions, a read-only filesystem, and credentials or a bucket policy that don't allow the operation.

Summary

Types

t()

@type t() :: %Fil.AccessDeniedError{
  __exception__: term(),
  disk: Fil.Disk.t() | nil,
  op: Fil.Op.name() | nil,
  path: String.t() | nil,
  reason: term()
}